color_groups_dict = {
	'pink':['deeppink','hotpink','lightpink','mediumvioletred','palevioletred','pink'],
	'red':['crimson','darkred','darksalmon','firebrick','orangered','indianred','lightcoral','lightsalmon','red','salmon'],
	'orange':['coral','darkorange','gold','orange','tomato'],
	'yellow':['darkkhaki','khaki','lemonchiffon','lightgoldenrodyellow','lightyellow','moccasin','palegoldenrod','papayawhip','yellow'],
	'brown':['bisque','blanchedalmond','brown','burlywood','chocolate','cornsilk','darkgoldenrod','goldenrod','maroon','peru','rosybrown','saddlebrown','sandybrown','sienna','tan','wheat'],
	'green':['chartreuse','darkgreen','darkolivegreen','darkseagreen','forestgreen','green','greenyellow','lawngreen','lightgreen','lime','limegreen','mediumseagreen','lightseagreen','mediumaquamarine','mediumspringgreen','olive','olivedrab','palegreen','seagreen','springgreen','yellowgreen'],
	'cyan':['cadetblue','mediumturquoise','cyan','darkcyan','lightcyan','teal'],
	'blue':['blue','blueviolet','darkturquoise','turquoise','cornflowerblue','darkblue','deepskyblue','dodgerblue','lightblue','lightskyblue','lightsteelblue','mediumblue','midnightblue','navy','powderblue','royalblue','skyblue','steelblue'],
	'purple':['darkmagenta','darkorchid','darkslateblue','darkviolet','fuchsia','indigo','lavender','magenta','mediumorchid','mediumpurple','mediumslateblue','orchid','plum','purple','rebbecapurple','slateblue','thistle','violet'],
	'gray':['aliceblue','antiquewhite','azure','beige','darkgray','darkslategray','dimgray','floralwhite','gainsboro','ghostwhite','gray','honeydew','ivory','lavenderblush','lightgray','lightslategray','linen','mintcream','mistyrose','navajowhite','oldlace','seashell','silver','slategray','snow','whitesmoke'],
	'black':[],
	'white':[]
}